@@ -269,8 +269,8 @@ namespace orc {
    private:
     std::unique_ptr<orc::RleDecoder> secondsRle;
     std::unique_ptr<orc::RleDecoder> nanoRle;
-    const Timezone& writerTimezone;
-    const Timezone& readerTimezone;
+    const Timezone* writerTimezone;
+    const Timezone* readerTimezone;
     const int64_t epochOffset;
     const bool sameTimezone;
 
@@ -288,10 +288,10 @@ namespace orc {
   TimestampColumnReader::TimestampColumnReader(const Type& type, StripeStreams& stripe,
                                                bool isInstantType)
       : ColumnReader(type, stripe),
-        writerTimezone(isInstantType ? getTimezoneByName("GMT") : stripe.getWriterTimezone()),
-        readerTimezone(isInstantType ? getTimezoneByName("GMT") : stripe.getReaderTimezone()),
-        epochOffset(writerTimezone.getEpoch()),
-        sameTimezone(&writerTimezone == &readerTimezone) {
+        writerTimezone(isInstantType ? &getTimezoneByName("GMT") : &stripe.getWriterTimezone()),
+        readerTimezone(isInstantType ? &getTimezoneByName("GMT") : &stripe.getReaderTimezone()),
+        epochOffset(writerTimezone->getEpoch()),
+        sameTimezone(writerTimezone == readerTimezone) {
     RleVersion vers = convertRleVersion(stripe.getEncoding(columnId).kind());
     std::unique_ptr<SeekableInputStream> stream =
         stripe.getStream(columnId, proto::Stream_Kind_DATA, true);
@@ -336,13 +336,13 @@ namespace orc {
         if (!sameTimezone) {
           // adjust timestamp value to same wall clock time if writer and reader
           // time zones have different rules, which is required for Apache Orc.
-          const auto& wv = writerTimezone.getVariant(writerTime);
-          const auto& rv = readerTimezone.getVariant(writerTime);
+          const auto& wv = writerTimezone->getVariant(writerTime);
+          const auto& rv = readerTimezone->getVariant(writerTime);
           if (!wv.hasSameTzRule(rv)) {
             // If the timezone adjustment moves the millis across a DST boundary,
             // we need to reevaluate the offsets.
             int64_t adjustedTime = writerTime + wv.gmtOffset - rv.gmtOffset;
-            const auto& adjustedReader = readerTimezone.getVariant(adjustedTime);
+            const auto& adjustedReader = readerTimezone->getVariant(adjustedTime);
             writerTime = writerTime + wv.gmtOffset - adjustedReader.gmtOffset;
           }
         }
@@ -567,7 +567,7 @@ namespace orc {
                                                              StripeStreams& stripe)
       : ColumnReader(type, stripe), dictionary(new StringDictionary(stripe.getMemoryPool())) {
     RleVersion rleVersion = convertRleVersion(stripe.getEncoding(columnId).kind());
-    uint32_t dictSize = stripe.getEncoding(columnId).dictionarysize();
+    uint32_t dictSize = stripe.getEncoding(columnId).dictionary_size();
     std::unique_ptr<SeekableInputStream> stream =
         stripe.getStream(columnId, proto::Stream_Kind_DATA, true);
     if (stream == nullptr) {
@@ -830,7 +830,7 @@ namespace orc {
     std::vector<std::unique_ptr<ColumnReader>> children;
 
    public:
-    StructColumnReader(const Type& type, StripeStreams& stipe, bool useTightNumericVector = false,
+    StructColumnReader(const Type& type, StripeStreams& stripe, bool useTightNumericVector = false,
                        bool throwOnSchemaEvolutionOverflow = false);
 
     uint64_t skip(uint64_t numValues) override;
