@@ -29,10 +29,9 @@ import org.apache.hadoop.hive.serde2.io.DateWritable;
 import org.apache.hadoop.hive.serde2.io.HiveDecimalWritable;
 import org.apache.hadoop.io.Text;
 import org.apache.orc.impl.ColumnStatisticsImpl;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TestName;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestInfo;
 
 import java.io.File;
 import java.math.BigDecimal;
@@ -42,9 +41,10 @@ import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.TimeZone;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 /**
  * Test ColumnStatisticsImpl for ORC.
@@ -154,12 +154,13 @@ public class TestColumnStatistics {
     final StringColumnStatistics typed = (StringColumnStatistics) stats1;
     final StringColumnStatistics typed2 = (StringColumnStatistics) stats2;
 
-    assertTrue("Upperbound cannot be more than 1024 bytes",
-        1024 >= typed.getUpperBound().getBytes(StandardCharsets.UTF_8).length);
-    assertTrue("Lowerbound cannot be more than 1024 bytes",1024 >= typed.getLowerBound().getBytes(StandardCharsets.UTF_8).length);
+    assertTrue(1024 >= typed.getUpperBound().getBytes(StandardCharsets.UTF_8).length,
+        "Upperbound cannot be more than 1024 bytes");
+    assertTrue(1024 >= typed.getLowerBound().getBytes(StandardCharsets.UTF_8).length,
+        "Lowerbound cannot be more than 1024 bytes");
 
-    assertEquals(null, typed.getMinimum());
-    assertEquals(null, typed.getMaximum());
+    assertNull(typed.getMinimum());
+    assertNull(typed.getMaximum());
 
     stats1.reset();
 
@@ -168,11 +169,13 @@ public class TestColumnStatistics {
     stats1.updateString(test.getBytes(StandardCharsets.UTF_8), 0,
         test.getBytes(StandardCharsets.UTF_8).length, 0);
 
-    assertTrue("Lowerbound cannot be more than 1024 bytes", 1024 >= typed.getLowerBound().getBytes(StandardCharsets.UTF_8).length);
-    assertTrue("Upperbound cannot be more than 1024 bytes", 1024 >= typed.getUpperBound().getBytes(StandardCharsets.UTF_8).length);
+    assertTrue(1024 >= typed.getLowerBound().getBytes(StandardCharsets.UTF_8).length,
+        "Lowerbound cannot be more than 1024 bytes");
+    assertTrue(1024 >= typed.getUpperBound().getBytes(StandardCharsets.UTF_8).length,
+            "Upperbound cannot be more than 1024 bytes");
 
-    assertEquals(null, typed.getMinimum());
-    assertEquals(null, typed.getMaximum());
+    assertNull(typed.getMinimum());
+    assertNull(typed.getMaximum());
 
     stats1.reset();
     /* test upper bound - merging  */
@@ -186,12 +189,12 @@ public class TestColumnStatistics {
     stats2.updateString(new Text(fragment));
 
     assertEquals("anne", typed2.getMinimum());
-    assertEquals(null, typed2.getMaximum());
+    assertNull(typed2.getMaximum());
 
     stats1.merge(stats2);
 
     assertEquals("anne", typed.getMinimum());
-    assertEquals(null, typed.getMaximum());
+    assertNull(typed.getMaximum());
 
 
     /* test lower bound - merging  */
@@ -207,7 +210,7 @@ public class TestColumnStatistics {
 
     stats1.merge(stats2);
 
-    assertEquals(null, typed.getMinimum());
+    assertNull(typed.getMinimum());
     assertEquals("jane", typed.getMaximum());
   }
 
@@ -229,8 +232,8 @@ public class TestColumnStatistics {
     StringColumnStatistics stringStats = (StringColumnStatistics) stats;
 
     // make sure that the min/max are null
-    assertEquals(null, stringStats.getMinimum());
-    assertEquals(null, stringStats.getMaximum());
+    assertNull(stringStats.getMinimum());
+    assertNull(stringStats.getMaximum());
     assertEquals(5 * 256, stringStats.getSum());
 
     // and that the lower and upper bound are correct
@@ -270,8 +273,8 @@ public class TestColumnStatistics {
     StringColumnStatistics stringStats = (StringColumnStatistics) stats;
 
     // make sure that the min/max are null
-    assertEquals(null, stringStats.getMinimum());
-    assertEquals(null, stringStats.getMaximum());
+    assertNull(stringStats.getMinimum());
+    assertNull(stringStats.getMaximum());
     assertEquals(2 * 5 * 256, stringStats.getSum());
 
     // and that the lower and upper bound are correct
@@ -299,8 +302,8 @@ public class TestColumnStatistics {
     StringColumnStatistics stringStats = (StringColumnStatistics) stats;
 
     // make sure that the min/max are null
-    assertEquals(null, stringStats.getMinimum());
-    assertEquals(null, stringStats.getMaximum());
+    assertNull(stringStats.getMinimum());
+    assertNull(stringStats.getMaximum());
     assertEquals(3 * 5 * 256, stringStats.getSum());
 
     // and that the lower and upper bound are correct
@@ -328,8 +331,8 @@ public class TestColumnStatistics {
     StringColumnStatistics stringStats = (StringColumnStatistics) stats;
 
     // make sure that the min/max are null
-    assertEquals(null, stringStats.getMinimum());
-    assertEquals(null, stringStats.getMaximum());
+    assertNull(stringStats.getMinimum());
+    assertNull(stringStats.getMaximum());
     assertEquals(4 * 5 * 256, stringStats.getSum());
 
     // and that the lower and upper bound are correct
@@ -383,8 +386,8 @@ public class TestColumnStatistics {
     ColumnStatisticsImpl stats2 =
         ColumnStatisticsImpl.deserialize(schema, serial);
     StringColumnStatistics typed2 = (StringColumnStatistics) stats2;
-    assertEquals(null, typed2.getMinimum());
-    assertEquals(null, typed2.getMaximum());
+    assertNull(typed2.getMinimum());
+    assertNull(typed2.getMaximum());
     assertEquals(lowerBound, typed2.getLowerBound());
     assertEquals(upperbound, typed2.getUpperBound());
     assertEquals(1764L, typed2.getSum());
@@ -405,15 +408,15 @@ public class TestColumnStatistics {
     stats2.increment(2);
     stats1.merge(stats2);
     DateColumnStatistics typed = (DateColumnStatistics) stats1;
-    assertEquals(new DateWritable(10).get(), typed.getMinimum());
-    assertEquals(new DateWritable(2000).get(), typed.getMaximum());
+    assertEquals(10, typed.getMinimumLocalDate().toEpochDay());
+    assertEquals(2000, typed.getMaximumLocalDate().toEpochDay());
     stats1.reset();
     stats1.updateDate(new DateWritable(-10));
     stats1.updateDate(new DateWritable(10000));
     stats1.increment(2);
     stats1.merge(stats2);
-    assertEquals(new DateWritable(-10).get(), typed.getMinimum());
-    assertEquals(new DateWritable(10000).get(), typed.getMaximum());
+    assertEquals(-10, typed.getMinimumLocalDate().toEpochDay());
+    assertEquals(10000, typed.getMaximumLocalDate().toEpochDay());
   }
 
   @Test
@@ -595,8 +598,8 @@ public class TestColumnStatistics {
     assertEquals("2000-04-02 03:30:00.0001", typed.getMaximum().toString());
 
     stats1.reset();
-    assertEquals(null, typed.getMinimum());
-    assertEquals(null, typed.getMaximum());
+    assertNull(typed.getMinimum());
+    assertNull(typed.getMaximum());
 
     stats1.updateTimestamp(Timestamp.valueOf( "1999-04-04 00:00:00.000231"));
     stats1.updateTimestamp(Timestamp.valueOf( "2009-03-08 12:00:00.000654"));
@@ -632,8 +635,8 @@ public class TestColumnStatistics {
     assertEquals("1969-12-31 16:00:00.0009", typed.getMaximum().toString());
 
     stats1.reset();
-    assertEquals(null, typed.getMinimum());
-    assertEquals(null, typed.getMaximum());
+    assertNull(typed.getMinimum());
+    assertNull(typed.getMaximum());
 
     stats1.updateTimestamp(Timestamp.valueOf("1969-12-31 15:00:00.0005"));
     stats1.increment(1);
@@ -690,8 +693,10 @@ public class TestColumnStatistics {
     Reader reader = OrcFile.createReader(testFilePath,
         OrcFile.readerOptions(conf).filesystem(fs));
     DecimalColumnStatistics statistics = (DecimalColumnStatistics) reader.getStatistics()[0];
-    assertEquals("Incorrect maximum value", new BigDecimal("-99999.99"), statistics.getMinimum().bigDecimalValue());
-    assertEquals("Incorrect minimum value", new BigDecimal("-88888.88"), statistics.getMaximum().bigDecimalValue());
+    assertEquals(new BigDecimal("-99999.99"), statistics.getMinimum().bigDecimalValue(),
+        "Incorrect maximum value");
+    assertEquals(new BigDecimal("-88888.88"), statistics.getMaximum().bigDecimalValue(),
+        "Incorrect minimum value");
   }
 
 
@@ -702,15 +707,13 @@ public class TestColumnStatistics {
   FileSystem fs;
   Path testFilePath;
 
-  @Rule
-  public TestName testCaseName = new TestName();
-
-  @Before
-  public void openFileSystem() throws Exception {
+  @BeforeEach
+  public void openFileSystem(TestInfo testInfo) throws Exception {
     conf = new Configuration();
     fs = FileSystem.getLocal(conf);
     fs.setWorkingDirectory(workDir);
-    testFilePath = new Path("TestOrcFile." + testCaseName.getMethodName() + ".orc");
+    testFilePath = new Path(
+        "TestOrcFile." + testInfo.getTestMethod().get().getName() + ".orc");
     fs.delete(testFilePath, false);
   }
 }
